@@ -22,10 +22,8 @@
 #include <config.h>
 #endif
 
-#include <X11/Xutil.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <vte/vte.h>
@@ -39,9 +37,6 @@
 #include "preferences.h"
 #include "unixsocket.h"
 
-/* X accessor. */
-static void gdk_window_get_geometry_hints(GdkWindow * window, GdkGeometry * geometry, GdkWindowHints * geometry_mask);
-
 /* Utilities. */
 static void terminal_get_border(Term * term, GtkBorder * border);
 static void terminal_save_size(LXTerminal * terminal);
@@ -57,6 +52,7 @@ static void terminal_new_window_activate_event(GtkAction * action, LXTerminal *
 static void terminal_new_tab_activate_event(GtkAction * action, LXTerminal * terminal);
 static void terminal_close_tab_activate_event(GtkAction * action, LXTerminal * terminal);
 static void terminal_close_window_activate_event(GtkAction * action, LXTerminal * terminal);
+static void terminal_open_url_activate_event(GtkAction * action, LXTerminal * terminal);
 static void terminal_copy_url_activate_event(GtkAction * action, LXTerminal * terminal);
 static void terminal_copy_activate_event(GtkAction * action, LXTerminal * terminal);
 static void terminal_paste_activate_event(GtkAction * action, LXTerminal * terminal);
@@ -156,6 +152,7 @@ static GtkActionEntry vte_menu_items[] =
     { "NewWindow", "list-add", N_("New _Window"), NULL, "New Window", G_CALLBACK(terminal_new_window_activate_event) },
     { "NewTab", "list-add", N_("New _Tab"), NULL, "New Tab", G_CALLBACK(terminal_new_tab_activate_event) },
     { "Sep1", NULL, "Sep" },
+    { "OpenURL", NULL, N_("Open _URL"), NULL, "Open URL", G_CALLBACK(terminal_open_url_activate_event) },
     { "CopyURL", NULL, N_("Copy _URL"), NULL, "Copy URL", G_CALLBACK(terminal_copy_url_activate_event) },
     { "Copy", "edit-copy", N_("Cop_y"), NULL, "Copy", G_CALLBACK(terminal_copy_activate_event) },
     { "Paste", "edit-paste", N_("_Paste"), NULL, "Paste", G_CALLBACK(terminal_paste_activate_event) },
@@ -255,7 +252,7 @@ static gchar * terminal_get_current_dir(LXTerminal * terminal)
 static const gchar * terminal_get_preferred_shell () {
     const gchar *shell;
     struct passwd *pw;
-    gchar *fallback_shell = "/bin/sh";
+    const gchar *fallback_shell = "/bin/sh";
 
     shell = g_getenv("SHELL");
     if (geteuid() == getuid() && getegid() == getgid()) {
@@ -478,6 +475,20 @@ static void terminal_close_window_activate_event(GtkAction * action, LXTerminal
     }
 }
 
+/* Handler for the "Open URL" right-click menu item.
+ * Fork+exec xdg-open the url. */
+static void terminal_open_url_activate_event(GtkAction * action, LXTerminal * terminal)
+{
+        Term * term = g_ptr_array_index(terminal->terms, gtk_notebook_get_current_page(GTK_NOTEBOOK(terminal->notebook)));
+        if (term->matched_url)
+        {
+                gchar * cmd = g_strdup_printf("xdg-open %s", term->matched_url);
+                if ( ! g_spawn_command_line_async(cmd, NULL))
+                        g_warning("Failed to launch xdg-open. The command was `%s'\n", cmd);
+                g_free(cmd);
+        }
+}
+
 /* Handler for the "Copy URL" right-click menu item.
  * Copy the URL to the clipboard. */
 static void terminal_copy_url_activate_event(GtkAction * action, LXTerminal * terminal)
@@ -552,29 +563,27 @@ static void terminal_name_tab_activate_event(GtkAction * action, LXTerminal * te
 {
     Term * term;
     gint current = gtk_notebook_get_current_page(GTK_NOTEBOOK(terminal->notebook));
-    if (current != -1)
-    {
-        /* Search for the Term structure corresponding to the current tab. */
-        guint i;
-        for (i = 0; i < terminal->terms->len; i++)
-        {
-            term = g_ptr_array_index(terminal->terms, i);
-            if (term->index == current)
-            {
-                break;
-            }
-        }
-    }
-    else
-    {
+    if (current == -1 || terminal->terms->len <= 0) {
         return;
     }
+
+    /* Search for the Term structure corresponding to the current tab. */
+    guint i;
+    for (i = 0; i < terminal->terms->len; i++)
+    {
+        term = g_ptr_array_index(terminal->terms, i);
+        if (term->index == current)
+        {
+            break;
+        }
+    }
+
     GtkWidget * dialog = gtk_dialog_new_with_buttons(
         _("Name Tab"),
         GTK_WINDOW(terminal->window),
         0,
-        NULL, GTK_RESPONSE_CANCEL,
-        NULL, GTK_RESPONSE_OK,
+        _("_Cancel"), GTK_RESPONSE_CANCEL,
+        _("_OK"), GTK_RESPONSE_OK,
         NULL);
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     if (gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), "lxterminal"))
@@ -688,6 +697,10 @@ static void terminal_zoom(LXTerminal * terminal)
     guint i;
     terminal_save_size(terminal);
 
+    if (terminal->terms->len <= 0) {
+        return;
+    }
+
     for (i = 0; i < terminal->terms->len; i++) {
         term = g_ptr_array_index(terminal->terms, i);
         vte_terminal_set_font_scale(VTE_TERMINAL(term->vte), terminal->scale);
@@ -827,18 +840,21 @@ static gboolean terminal_close_window_confirmation_dialog(LXTerminal * terminal)
 /* Weak-notify callback for LXTerminal object. */
 static void terminal_window_exit(LXTerminal * terminal, GObject * where_the_object_was)
 {
+    LXTermWindow * lxtermwin = terminal->parent;
+
     /* If last window, exit main loop. */
-    if (terminal->parent->windows->len == 1)
+    if (lxtermwin->windows->len == 1) {
         gtk_main_quit();
+    }
 
     else
     {
         /* Remove the element and decrease the index number of each succeeding element. */
-        g_ptr_array_remove_index(terminal->parent->windows, terminal->index);
+        g_ptr_array_remove_index(lxtermwin->windows, terminal->index);
         guint i;
-        for (i = terminal->index; i < terminal->parent->windows->len; i++)
+        for (i = terminal->index; i < lxtermwin->windows->len; i++)
         {
-            LXTerminal * t = g_ptr_array_index(terminal->parent->windows, i);
+            LXTerminal * t = g_ptr_array_index(lxtermwin->windows, i);
             t->index --;
         }
 
@@ -915,7 +931,7 @@ static gchar * terminal_get_match_at(VteTerminal * vte, Term * term, GdkEventBut
 {
 #if VTE_CHECK_VERSION (0, 38, 0)
     gint tag;
-    return vte_terminal_match_check_event(vte, event, &tag);
+    return vte_terminal_match_check_event(vte, (GdkEvent *) event, &tag);
 #else
     /* steal from tilda-0.09.6/src/tilda_terminal.c:743
      * See if the terminal has matched the regular expression. */
@@ -959,8 +975,11 @@ static void terminal_show_popup_menu(VteTerminal * vte, GdkEventButton * event,
     term->matched_url = terminal_get_match_at(vte, term, event);
 
     GtkAction * action_copy_url = gtk_ui_manager_get_action(manager, "/VTEMenu/CopyURL");
-    if (action_copy_url)
+    GtkAction * action_open_url = gtk_ui_manager_get_action(manager, "/VTEMenu/OpenURL");
+    if (action_copy_url) {
         gtk_action_set_visible(action_copy_url, term->matched_url != NULL);
+        gtk_action_set_visible(action_open_url, term->matched_url != NULL);
+    }
 
     gtk_menu_popup(GTK_MENU(gtk_ui_manager_get_widget(manager, "/VTEMenu")),
         NULL, NULL, NULL, NULL, event->button, event->time);
@@ -972,18 +991,18 @@ static void terminal_vte_cursor_moved_event(VteTerminal * vte, Term * term)
     LXTerminal * terminal = term->parent;
     Term * activeterm = g_ptr_array_index(terminal->terms, gtk_notebook_get_current_page(GTK_NOTEBOOK(terminal->notebook)));
     /* If the activity is in a background tab, set its label to bold */
-    if ( activeterm != term )
-        if (term->user_specified_label)
-        {
+    if ( activeterm != term ) {
+        if (term->user_specified_label) {
             const gchar *currentcustomtitle=gtk_label_get_text(GTK_LABEL(term->label));
             /* Only add an asterisk if there isn't none already */
             if (!g_str_has_prefix(currentcustomtitle,"* "))
                 currentcustomtitle=g_strconcat("* ",currentcustomtitle,NULL);
 
             gtk_label_set_markup(GTK_LABEL(term->label),g_strconcat("<b>",currentcustomtitle,"</b>",NULL));
-        }
-        else
+        } else {
             gtk_label_set_markup(GTK_LABEL(term->label),g_strconcat("<b>* ",vte_terminal_get_window_title(VTE_TERMINAL(vte)),"</b>",NULL));
+	}
+    }
 }
 
 /* Handler for "button-press-event" signal on VTE. */
@@ -1075,6 +1094,7 @@ static void terminal_settings_apply_to_term(LXTerminal * terminal, Term * term)
     {
         vte_terminal_set_background_transparent(VTE_TERMINAL(term->vte), setting->background_alpha == 65535 ? FALSE : TRUE);
         vte_terminal_set_background_saturation(VTE_TERMINAL(term->vte), 1 - ((double) setting->background_alpha / 65535));
+        vte_terminal_set_background_tint_color(VTE_TERMINAL(term->vte), &setting->background_color);
     }
 #endif
 
