@@ -64,20 +64,20 @@
 #define ZOOM_OUT_ACCEL "zoom_out_accel"
 #define ZOOM_RESET_ACCEL "zoom_reset_accel"
 
-#define NEW_WINDOW_ACCEL_DEF "<CTRL><SHIFT>N"
-#define NEW_TAB_ACCEL_DEF "<CTRL><SHIFT>T"
-#define CLOSE_TAB_ACCEL_DEF "<CTRL><SHIFT>W"
-#define CLOSE_WINDOW_ACCEL_DEF "<CTRL><SHIFT>Q"
-#define COPY_ACCEL_DEF "<CTRL><SHIFT>C"
-#define PASTE_ACCEL_DEF "<CTRL><SHIFT>V"
-#define NAME_TAB_ACCEL_DEF "<CTRL><SHIFT>I"
-#define PREVIOUS_TAB_ACCEL_DEF "<CTRL>Page_Up"
-#define NEXT_TAB_ACCEL_DEF "<CTRL>Page_Down"
-#define MOVE_TAB_LEFT_ACCEL_DEF "<CTRL><SHIFT>Page_Up"
-#define MOVE_TAB_RIGHT_ACCEL_DEF "<CTRL><SHIFT>Page_Down"
-#define ZOOM_IN_ACCEL_DEF "<CTRL>plus"
-#define ZOOM_OUT_ACCEL_DEF "<CTRL>underscore"
-#define ZOOM_RESET_ACCEL_DEF "<CTRL>parenright"
+#define NEW_WINDOW_ACCEL_DEF "<Primary><Shift>n"
+#define NEW_TAB_ACCEL_DEF "<Primary><Shift>t"
+#define CLOSE_TAB_ACCEL_DEF "<Primary><Shift>w"
+#define CLOSE_WINDOW_ACCEL_DEF "<Primary><Shift>q"
+#define COPY_ACCEL_DEF "<Primary><Shift>c"
+#define PASTE_ACCEL_DEF "<Primary><Shift>v"
+#define NAME_TAB_ACCEL_DEF "<Primary><Shift>i"
+#define PREVIOUS_TAB_ACCEL_DEF "<Primary>Page_Up"
+#define NEXT_TAB_ACCEL_DEF "<Primary>Page_Down"
+#define MOVE_TAB_LEFT_ACCEL_DEF "<Primary><Shift>Page_Up"
+#define MOVE_TAB_RIGHT_ACCEL_DEF "<Primary><Shift>Page_Down"
+#define ZOOM_IN_ACCEL_DEF "<Primary><Shift>plus"
+#define ZOOM_OUT_ACCEL_DEF "<Primary><Shift>underscore"
+#define ZOOM_RESET_ACCEL_DEF "<Primary><Shift>parenright"
 
 /* User preferences. */
 typedef struct _setting {
@@ -94,7 +94,7 @@ typedef struct _setting {
     GdkColor foreground_color;      /* Foreground color */
     GdkColor palette_color[16];      /* Palette colors */
 #endif
-    char * color_preset;        /* Color preset name */
+    const char * color_preset;        /* Color preset name */
     gboolean disallow_bold;     /* Disallow bolding by VTE */
     gboolean cursor_blink;      /* True if cursor blinks */
     gboolean cursor_underline;      /* True if underline cursor; false if block cursor */
@@ -134,10 +134,10 @@ typedef struct _setting {
 
 /* Colors use char for Gdk2 and Gdk3 compability and less duplication */
 typedef struct _colorpreset {
-    char * name;
-    char * background_color;
-    char * foreground_color;
-    char * palette[16];
+    const char * name;
+    const char * background_color;
+    const char * foreground_color;
+    const char * palette[16];
 } ColorPreset;
 
 extern Setting * get_setting();
